[Pkg-haskell-commits] [SCM] haskell-testpack branch, master, updated. debian/1.0.2-1-4-gb0d6b36
John Goerzen
jgoerzen at complete.org
Fri Apr 23 15:17:22 UTC 2010
The following commit has been merged in the master branch:
commit 447e3ca87b8dc33e472f41be51b7b1eca22e2a52
Author: John Goerzen <jgoerzen at complete.org>
Date: Sun Dec 3 09:25:48 2006 +0100
Renamed MissingH.ConfigParser to Data.ConfigFile
diff --git a/MissingH.cabal b/MissingH.cabal
index d1ab375..0af914c 100644
--- a/MissingH.cabal
+++ b/MissingH.cabal
@@ -34,10 +34,10 @@ Exposed-Modules: MissingH.Str, MissingH.IO, MissingH.IO.Binary, MissingH.List,
MissingH.Network.SocketServer,
MissingH.Either,
MissingH.Maybe,
- MissingH.ConfigParser,
- MissingH.ConfigParser.Types,
- MissingH.ConfigParser.Parser,
- MissingH.ConfigParser.Lexer,
+ Data.ConfigFile,
+ Data.ConfigFile.Types,
+ Data.ConfigFile.Parser,
+ Data.ConfigFile.Lexer,
Data.Bits.Utils,
Data.Hash.CRC32.Posix, Data.Hash.CRC32.GZip,
Data.Hash.MD5, Data.Hash.MD5.Zord64_HARD,
diff --git a/MissingH/ConfigParser/Lexer.hs b/MissingH/ConfigParser/Lexer.hs
index dd08fd6..05a8769 100644
--- a/MissingH/ConfigParser/Lexer.hs
+++ b/MissingH/ConfigParser/Lexer.hs
@@ -17,7 +17,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-}
{- |
- Module : MissingH.ConfigParser.Lexer
+ Module : Data.ConfigFile.Lexer
Copyright : Copyright (C) 2004 John Goerzen
License : GNU GPL, version 2 or above
@@ -25,12 +25,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Stability : provisional
Portability: portable
-Lexer support for "MissingH.ConfigParser". This module is not intended to be
+Lexer support for "Data.ConfigFile". This module is not intended to be
used directly by your programs.
Copyright (c) 2004 John Goerzen, jgoerzen\@complete.org
-}
-module MissingH.ConfigParser.Lexer
+module Data.ConfigFile.Lexer
(
-- -- * Temporary for testing
--comment_chars, eol, optionsep, whitespace_chars, comment_line,
diff --git a/MissingH/ConfigParser/Parser.hs b/MissingH/ConfigParser/Parser.hs
index 9087d02..31eafec 100644
--- a/MissingH/ConfigParser/Parser.hs
+++ b/MissingH/ConfigParser/Parser.hs
@@ -17,7 +17,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-}
{- |
- Module : MissingH.ConfigParser.Parser
+ Module : Data.ConfigFile.Parser
Copyright : Copyright (C) 2004 John Goerzen
License : GNU GPL, version 2 or above
@@ -25,12 +25,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Stability : provisional
Portability: portable
-Parser support for "MissingH.ConfigParser". This module is not intended to be
+Parser support for "Data.ConfigFile". This module is not intended to be
used directly by your programs.
Copyright (c) 2004 John Goerzen, jgoerzen\@complete.org
-}
-module MissingH.ConfigParser.Parser
+module Data.ConfigFile.Parser
(
parse_string, parse_file, parse_handle, interpmain, ParseOutput
--satisfyG,
@@ -39,10 +39,10 @@ module MissingH.ConfigParser.Parser
import Text.ParserCombinators.Parsec
import Control.Monad.Error(throwError, MonadError)
import MissingH.Str
-import MissingH.ConfigParser.Lexer
+import Data.ConfigFile.Lexer
import System.IO(Handle, hGetContents)
import MissingH.Parsec
-import MissingH.ConfigParser.Types
+import Data.ConfigFile.Types
----------------------------------------------------------------------
-- Exported funcs
diff --git a/MissingH/ConfigParser.hs b/src/Data/ConfigFile.hs
similarity index 99%
rename from MissingH/ConfigParser.hs
rename to src/Data/ConfigFile.hs
index 1b4024c..e622be0 100644
--- a/MissingH/ConfigParser.hs
+++ b/src/Data/ConfigFile.hs
@@ -17,7 +17,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-}
{- |
- Module : MissingH.ConfigParser
+ Module : Data.ConfigFile
Copyright : Copyright (C) 2004-2006 John Goerzen
License : GNU GPL, version 2 or above
@@ -31,7 +31,7 @@ Copyright (c) 2004-2006 John Goerzen, jgoerzen\@complete.org
This module contains extensive documentation. Please scroll down to the Introduction section to continue reading.
-}
-module MissingH.ConfigParser
+module Data.ConfigFile
(
-- * Introduction
-- $introduction
@@ -103,8 +103,8 @@ module MissingH.ConfigParser
) where
-import MissingH.ConfigParser.Types
-import MissingH.ConfigParser.Parser
+import Data.ConfigFile.Types
+import Data.ConfigFile.Parser
import MissingH.Map
import MissingH.Either
import MissingH.Str
@@ -123,7 +123,7 @@ import Text.ParserCombinators.Parsec(parse)
-- Basic types / default values
----------------------------------------------------------------------
-{- | The default empty 'MissingH.ConfigParser' object.
+{- | The default empty 'Data.ConfigFile' object.
The content contains only an empty mandatory @DEFAULT@ section.
@@ -790,7 +790,7 @@ Using Haskell's monad transformers, you can run it in the combined
Error\/IO monad. That is, you will get an IO result back. Here is a full
standalone example of doing that:
->import MissingH.ConfigParser
+>import Data.ConfigFile
>import Control.Monad.Error
>
>main = do
diff --git a/testsrc/ConfigParser/Maintest.hs b/testsrc/ConfigParser/Maintest.hs
index 6abe033..b165e16 100644
--- a/testsrc/ConfigParser/Maintest.hs
+++ b/testsrc/ConfigParser/Maintest.hs
@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
module ConfigParser.Maintest(tests) where
import Test.HUnit
-import MissingH.ConfigParser
+import Data.ConfigFile
import MissingH.Either
import MissingH.IO.PlafCompat(nullFileName)
import MissingH.HUnit
diff --git a/testsrc/ConfigParser/Parsertest.hs b/testsrc/ConfigParser/Parsertest.hs
index bd4b79b..87a23b3 100644
--- a/testsrc/ConfigParser/Parsertest.hs
+++ b/testsrc/ConfigParser/Parsertest.hs
@@ -18,8 +18,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
module ConfigParser.Parsertest(tests) where
import Test.HUnit
-import MissingH.ConfigParser.Parser
-import MissingH.ConfigParser.Types
+import Data.ConfigFile.Parser
+import Data.ConfigFile.Types
import MissingH.HUnit
import Control.Exception
diff --git a/MissingH/ConfigParser/Types.hs b/MissingH/ConfigParser/Types.hs
index 64abb24..b789607 100644
--- a/MissingH/ConfigParser/Types.hs
+++ b/MissingH/ConfigParser/Types.hs
@@ -17,7 +17,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-}
{- |
- Module : MissingH.ConfigParser.Types
+ Module : Data.ConfigFile.Types
Copyright : Copyright (C) 2004-2005 John Goerzen
License : GNU GPL, version 2 or above
@@ -25,13 +25,13 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Stability : provisional
Portability: portable
-Internal types for "MissingH.ConfigParser". This module is not intended to be
+Internal types for "Data.ConfigFile". This module is not intended to be
used directly by your programs.
Copyright (c) 2004 John Goerzen, jgoerzen\@complete.org
-}
-module MissingH.ConfigParser.Types (
+module Data.ConfigFile.Types (
CPOptions, CPData,
CPErrorData(..), CPError, {-CPResult,-}
ConfigParser(..),
@@ -58,10 +58,10 @@ type CPOptions = Map.Map OptionSpec String
{- | The main data storage type (storage of sections).
PLEASE NOTE: This type is exported only for use by other modules under
-MissingH.ConfigParser. You should NEVER access the FiniteMap in a ConfigParser
+Data.ConfigFile. You should NEVER access the FiniteMap in a ConfigParser
directly. This type may change in future releases of MissingH, which could
break your programs. Please retrict yourself to the interface in
-'MissingH.ConfigParser'.
+'Data.ConfigFile'.
-}
type CPData = Map.Map SectionSpec CPOptions
@@ -71,7 +71,7 @@ data CPErrorData = ParseError String -- ^ Parse error
| NoSection SectionSpec -- ^ The section does not exist
| NoOption OptionSpec -- ^ The option does not exist
| OtherProblem String -- ^ Miscellaneous error
- | InterpolationError String -- ^ Raised by 'MissingH.ConfigParser.interpolatingAccess' if a request was made for a non-existant option
+ | InterpolationError String -- ^ Raised by 'Data.ConfigFile.interpolatingAccess' if a request was made for a non-existant option
deriving (Eq, Ord, Show)
{- | Indicates an error occurred. The String is an explanation of the location
@@ -89,7 +89,7 @@ an error, while a Right value indicates success.
type CPResult a = MonadError CPError m => m a
-}
-{- | This is the main record that is used by 'MissingH.ConfigParser'.
+{- | This is the main record that is used by 'Data.ConfigFile'.
-}
data ConfigParser = ConfigParser
{ -- | The data itself
--
haskell-testpack
More information about the Pkg-haskell-commits
mailing list